--[[
    This file contains all the default magazine data.
]]


--[[  ORGM.registerMagazine(name, definition)

    Registers a magazine type with ORGM.  This must be called before any registerFirearm that plans to use that magazine. 
    
    name = the string name of the magazine (without module prefix)
    definition = a table containing the magazine stats. Valid table keys/value pairs are:
        moduleName = nil | string, module name this item is from. If nil, ORGM is used
        ammoType = string, the name of a ammo 'dummy round' (not real ammo name)
        reloadTime = nil | integer, if nil then ORGM.Settings.DefaultMagazineReoadTime is used
        maxCapacity = int, the max amount of bullets this magazine can hold
        ejectSound = nil | string, the string name of a sound file. If nil 'ORGMMagLoad' is used
        insertSound = nil | string, the string name of a sound file. If nil 'ORGMMagLoad' is used

    returns true on success, false if the magazine fails to register

]]
local register = ORGM.registerMagazine


register("AIAW308Mag", 
    { ammoType = 'Ammo_308Winchester', maxCapacity = 5, }
)
register("AKMMag", 
    { ammoType = 'Ammo_762x39mm', maxCapacity = 30, }
)
register("AM180Mag",
    { ammoType = 'Ammo_22LR', maxCapacity = 177, }
)
register("AR10Mag", 
    { ammoType = 'Ammo_762x51mm', maxCapacity = 20, }
)
register("AutomagVMag", 
    { ammoType = 'Ammo_50AE', maxCapacity = 5, }
)
register("BBPistolMag", 
    { ammoType = 'Ammo_117BB', maxCapacity = 35, reloadTime = 5, }
)
register("Ber92Mag", 
    { ammoType = 'Ammo_9x19mm', maxCapacity = 15, }
)
register("Ber93RMag", 
    { ammoType = 'Ammo_9x19mm', maxCapacity = 32, }
)
register("BLRMag", 
    { ammoType = 'Ammo_308Winchester', maxCapacity = 4, }
)
register("BrenTenMag", 
    { ammoType = 'Ammo_10x25mm', maxCapacity = 12, }
)
register("BrownHPMag", 
    { ammoType = 'Ammo_9x19mm', maxCapacity = 13, }
)
register("Colt38SMag", 
    { ammoType = 'Ammo_38Super', maxCapacity = 9, }
)
register("ColtDeltaMag", 
    { ammoType = 'Ammo_10x25mm', maxCapacity = 8, }
)
register("CZ75Mag", 
    { ammoType = 'Ammo_9x19mm', maxCapacity = 15, }
)
register("DEagleMag", 
    { ammoType = 'Ammo_44Magnum', maxCapacity = 8, }
)
register("DEagleXIXMag", 
    { ammoType = 'Ammo_50AE', maxCapacity = 7, }
)
register("FN57Mag", 
    { ammoType = 'Ammo_57x28mm', maxCapacity = 20, }
)
register("FNFALAMag", 
    { ammoType = 'Ammo_762x51mm', maxCapacity = 20, }
)
register("FNFALMag", 
    { ammoType = 'Ammo_308Winchester', maxCapacity = 20, }
)
register("FNP90Mag", 
    { ammoType = 'Ammo_57x28mm', maxCapacity = 50, }
)
register("GarandClip", 
    { ammoType = 'Ammo_3006Springfield', maxCapacity = 8, }
)
register("Glock17Mag",
    { ammoType = 'Ammo_9x19mm', maxCapacity = 17, }
)
register("Glock20Mag",
    { ammoType = 'Ammo_10x25mm', maxCapacity = 15, }
)
register("Glock21Mag",
    { ammoType = 'Ammo_45ACP', maxCapacity = 13, }
)
register("Glock22Mag",
    { ammoType = 'Ammo_40SW', maxCapacity = 10, }
)
register("HK91Mag",
    { ammoType = 'Ammo_308Winchester', maxCapacity = 20, }
)
register("HKG3Mag",
    { ammoType = 'Ammo_762x51mm', maxCapacity = 20, }
)
register("HKMK23Mag",
    { ammoType = 'Ammo_45ACP', maxCapacity = 12, }
)
register("HKMP5Mag",
    { ammoType = 'Ammo_9x19mm', maxCapacity = 30, }
)
register("HKSL8Mag",
    { ammoType = 'Ammo_223Remington', maxCapacity = 10, }
)
register("HKUMPMag",
    { ammoType = 'Ammo_45ACP', maxCapacity = 25, }
)
register("KahrCT40Mag",
    { ammoType = 'Ammo_40SW', maxCapacity = 7, }
)
register("KahrP380Mag",
    { ammoType = 'Ammo_380ACP', maxCapacity = 6, }
)
register("KTP32Mag",
    { ammoType = 'Ammo_32ACP', maxCapacity = 7, }
)
register("L96Mag",
    { ammoType = 'Ammo_762x51mm', maxCapacity = 5, }
)
register("LENo4Mag",
    { ammoType = 'Ammo_762x51mm', maxCapacity = 10, }
)
register("LENo4StripperClip",
    { ammoType = 'Ammo_762x51mm', maxCapacity = 5, }
)
register("M1216Mag",
    { ammoType = 'Ammo_12g', maxCapacity = 16, reloadTime = 15, ejectSound = 'ORGMShotgunRoundIn', insertSound = 'ORGMShotgunRoundIn', }
)
register("M1903StripperClip",
    { ammoType = 'Ammo_3006Springfield', maxCapacity = 5, reloadTime = 15, }
)
register("M1911Mag",
    { ammoType = 'Ammo_45ACP', maxCapacity = 7, }
)
register("M1A1Mag",
    { ammoType = 'Ammo_45ACP', maxCapacity = 30, }
)
register("M21Mag",
    { ammoType = 'Ammo_762x51mm', maxCapacity = 20, }
)
register("M249Belt",
    { ammoType = 'Ammo_556x45mm', maxCapacity = 200, }
)
register("Mac10Mag",
    { ammoType = 'Ammo_45ACP', maxCapacity = 30, }
)
register("Mac11Mag",
    { ammoType = 'Ammo_380ACP', maxCapacity = 32, }
)
register("Mini14Mag",
    { ammoType = 'Ammo_223Remington', maxCapacity = 20, }
)
register("MosinStripperClip",
    { ammoType = 'Ammo_762x54mm', maxCapacity = 5, reloadTime = 15, }
)
register("R25Mag",
    { ammoType = 'Ammo_308Winchester', maxCapacity = 10, }
)
register("Rem788Mag",
    { ammoType = 'Ammo_3030Winchester', maxCapacity = 3, }
)
register("Rug1022Mag",
    { ammoType = 'Ammo_22LR', maxCapacity = 25, }
)
register("RugerMKIIMag",
    { ammoType = 'Ammo_22LR', maxCapacity = 10, }
)
register("RugerSR9Mag",
    { ammoType = 'Ammo_9x19mm', maxCapacity = 17, }
)
register("SIG550Mag",
    { ammoType = 'Ammo_556x45mm', maxCapacity = 30, }
)
register("SIGP226Mag",
    { ammoType = 'Ammo_40SW', maxCapacity = 12, }
)
register("SkorpionMag",
    { ammoType = 'Ammo_32ACP', maxCapacity = 20, }
)
register("SKSStripperClip",
    { ammoType = 'Ammo_762x39mm', maxCapacity = 10, reloadTime = 15, }
)
register("SpeedLoader10mm6",
    { ammoType = 'Ammo_10x25mm', maxCapacity = 6, reloadTime = 15, }
)
register("SpeedLoader3576",
    { ammoType = 'Ammo_357Magnum', maxCapacity = 6, reloadTime = 15, }
)
register("SpeedLoader385",
    { ammoType = 'Ammo_38Special', maxCapacity = 5, reloadTime = 15, }
)
register("SpeedLoader386",
    { ammoType = 'Ammo_38Special', maxCapacity = 6, reloadTime = 15, }
)
register("SpeedLoader446",
    { ammoType = 'Ammo_44Magnum', maxCapacity = 6, reloadTime = 15, }
)
register("SpeedLoader4546",
    { ammoType = 'Ammo_454Casull', maxCapacity = 6, reloadTime = 15, }
)
register("SpeedLoader456",
    { ammoType = 'Ammo_45ACP', maxCapacity = 6, reloadTime = 15, }
)
register("SpeedLoader45C6",
    { ammoType = 'Ammo_45Colt', maxCapacity = 6, reloadTime = 15, }
)
register("Spr19119Mag",
    { ammoType = 'Ammo_9x19mm', maxCapacity = 9, }
)
register("SR25Mag",
    { ammoType = 'Ammo_762x51mm', maxCapacity = 20, }
)
register("STANAGMag",
    { ammoType = 'Ammo_556x45mm', maxCapacity = 30, }
)
register("SVDMag",
    { ammoType = 'Ammo_762x54mm', maxCapacity = 10, }
)
register("Taurus38Mag",
    { ammoType = 'Ammo_38Super', maxCapacity = 10, }
)
register("TaurusP132Mag",
    { ammoType = 'Ammo_32ACP', maxCapacity = 10, }
)
register("UziMag",
    { ammoType = 'Ammo_9x19mm', maxCapacity = 32, }
)
register("VEPR12Mag",
    { ammoType = 'Ammo_12g', maxCapacity = 8, reloadTime = 15, ejectSound = 'ORGMShotgunRoundIn', insertSound = 'ORGMShotgunRoundIn', }
)
register("WaltherP22Mag",
    { ammoType = 'Ammo_22LR', maxCapacity = 10, }
)
register("WaltherPPKMag",
    { ammoType = 'Ammo_380ACP', maxCapacity = 6, }
)
register("XD40Mag",
    { ammoType = 'Ammo_40SW', maxCapacity = 9, }
)

ORGM.log(ORGM.INFO, "All default magazines registered.")